@@ -38,10 +38,10 @@ emacspeak modules:
 
 """
 
-__id__ = "$Id: espeechfactory.py,v 1.10 2006/06/02 21:38:46 richb Exp $"
+__id__ = "$Id: espeechfactory.py,v 1.11 2006/09/08 15:48:59 richb Exp $"
 __author__ = "$Author: richb $"
-__version__ = "$Revision: 1.10 $"
-__date__ = "$Date: 2006/06/02 21:38:46 $"
+__version__ = "$Revision: 1.11 $"
+__date__ = "$Date: 2006/09/08 15:48:59 $"
 __copyright__ = "Copyright (c) 2005 Google Inc."
 __license__ = "LGPL"
 __all__=['Speaker']
@@ -49,6 +49,7 @@ __all__=['Speaker']
 import os
 
 import debug
+import settings
 import speechserver
 
 from orca_i18n import _           # for gettext support
@@ -243,6 +244,12 @@ class SpeechServer(speechserver.SpeechServer):
 
     def speak(self, text="", acss=None, interrupt=True):
         """Speaks specified text. All queued text is spoken immediately."""
+
+        # If the user has speech turned off, just return.
+        #
+        if not settings.enableSpeech:
+            return
+
         if acss:
             code =self.getvoice(acss)
             self._output.write("q {%s %s %s}\nd\n" %(code[0], text, code[1]))
