@@ -19,9 +19,9 @@
 
 """Provides a SpeechServer factory for gnome-speech drivers."""
 
-__id__        = "$Id: gnomespeechfactory.py 1388 2006-08-30 12:35:15Z wwalker $"
-__version__   = "$Revision: 1388 $"
-__date__      = "$Date: 2006-08-30 08:35:15 -0400 (Wed, 30 Aug 2006) $"
+__id__        = "$Id: gnomespeechfactory.py,v 1.53 2006/09/08 15:48:58 richb Exp $"
+__version__   = "$Revision: 1.53 $"
+__date__      = "$Date: 2006/09/08 15:48:58 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -666,6 +666,11 @@ class SpeechServer(speechserver.SpeechServer):
         be spoken.
         """
 
+        # If the user has speech turned off, just return.
+        #
+        if not settings.enableSpeech:
+            return -1
+
         speaker = self.__getSpeaker(acss)
         if acss and not acss.has_key(ACSS.RATE):
             voices = settings.voices
