@@ -20,9 +20,9 @@
 """Provides support for defining keybindings and matching them to input
 events."""
 
-__id__        = "$Id: keybindings.py 1249 2006-07-28 17:57:16Z richb $"
-__version__   = "$Revision: 1249 $"
-__date__      = "$Date: 2006-07-28 13:57:16 -0400 (Fri, 28 Jul 2006) $"
+__id__        = "$Id: keybindings.py,v 1.9 2006/09/28 22:11:09 lmonsanto Exp $"
+__version__   = "$Revision: 1.9 $"
+__date__      = "$Date: 2006/09/28 22:11:09 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -51,11 +51,13 @@ def _getKeycode(keysym):
     Returns an integer representing a key code that should match the
     event.hw_code for key events.
     """
-
     if not _keycodeCache.has_key(keysym):
         keymap = gtk.gdk.keymap_get_default()
-        entries = keymap.get_entries_for_keyval(
-            gtk.gdk.keyval_from_name(keysym))
+        keyval = gtk.gdk.keyval_from_name(keysym)
+        if keyval == 0:
+            return 0
+        entries = keymap.get_entries_for_keyval(keyval)
+            
         if entries:
             _keycodeCache[keysym] = entries[0][0]
         else:
