@@ -19,9 +19,9 @@
 
 """The main module for the Orca screen reader."""
 
-__id__        = "$Id: orca.py,v 1.150 2006/07/28 17:57:16 richb Exp $"
-__version__   = "$Revision: 1.150 $"
-__date__      = "$Date: 2006/07/28 17:57:16 $"
+__id__        = "$Id: orca.py,v 1.160 2006/10/02 19:28:56 richb Exp $"
+__version__   = "$Revision: 1.160 $"
+__date__      = "$Date: 2006/10/02 19:28:56 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -54,7 +54,7 @@ import platform
 import rolenames
 import settings
 import speech
-    
+
 import threading
 import util
 
@@ -647,7 +647,7 @@ def _processKeyboardEvent(event):
     """
     global _orcaModifierPressed
 
-    orca_state.lastInputEvent = event.timestamp
+    orca_state.lastInputEventTimestamp = event.timestamp
 
     # Log the keyboard event for future playback, if desired.
     # Note here that the key event_string being output is
@@ -657,7 +657,8 @@ def _processKeyboardEvent(event):
     #
     string = atspi.KeystrokeListener.keyEventToString(event)
     if _recordingKeystrokes and _keystrokesFile \
-       and (event.event_string != "Pause"):
+       and (event.event_string != "Pause") \
+       and (event.event_string != "F21"):
         _keystrokesFile.write(string + "\n")
     debug.printInputEvent(debug.LEVEL_FINE, string)
 
@@ -844,6 +845,8 @@ def loadUserSettings(script=None, inputEvent=None):
         debug.println(debug.LEVEL_CONFIGURATION,
                       "Magnification module has NOT been initialized.")
 
+    _showMainWindowGUI()
+
     httpserver.init()
 
     return True
@@ -867,6 +870,27 @@ def _showPreferencesGUI(script=None, inputEvent=None):
 
     return True
 
+def _showMainWindowGUI(script=None, inputEvent=None):
+    """Displays the Orca main window.
+
+    Returns True to indicate the input event has been consumed.
+    """
+
+    try:
+        module = __import__(settings.mainWindowModule,
+                            globals(),
+                            locals(),
+                            [''])
+        if settings.showMainWindow:
+            module.showMainUI()
+        else:
+            module.hideMainUI()
+    except:
+        debug.printException(debug.LEVEL_SEVERE)
+        pass
+
+    return True
+
 def _showPreferencesConsole(script=None, inputEvent=None):
     """Displays the user interace to configure Orca and set up
     user preferences via a command line interface.
@@ -886,6 +910,24 @@ def _showPreferencesConsole(script=None, inputEvent=None):
 
     return True
 
+def _showQuitGUI(script=None, inputEvent=None):
+    """Displays the user interace to quit Orca.
+
+    Returns True to indicate the input event has been consumed.
+    """
+
+    try:
+        module = __import__(settings.quitModule,
+                            globals(),
+                            locals(),
+                            [''])
+        module.showQuitUI()
+    except:
+        debug.printException(debug.LEVEL_SEVERE)
+        pass
+
+    return True
+
 # If True, this module has been initialized.
 #
 _initialized = False
@@ -1098,6 +1140,7 @@ def usage():
     print _("-s, --setup, --gui-setup     Set up user preferences")
     print _("-t, --text-setup             Set up user preferences (text version)")
     print _("-n, --no-setup               Skip set up of user preferences")
+    print _("-q, --quit                   Quits Orca (if shell script used)")
     print
     print _("If Orca has not been previously set up by the user, Orca\nwill automatically launch the preferences set up unless\nthe -n or --no-setup option is used.")
     print
@@ -1129,7 +1172,8 @@ def main():
     desktopRunning = False
     try:
         import gtk
-        desktopRunning = True
+        if gtk.gdk.display_get_default():
+            desktopRunning = True
     except:
         pass
 
