@@ -33,9 +33,9 @@ created in their own module.  The module defining the Script subclass
 is also required to have a 'getScript(app)' method that returns an
 instance of the Script subclass.  See default.py for an example."""
 
-__id__        = "$Id: script.py 1058 2006-06-16 14:05:56Z wwalker $"
-__version__   = "$Revision: 1058 $"
-__date__      = "$Date: 2006-06-16 10:05:56 -0400 (Fri, 16 Jun 2006) $"
+__id__        = "$Id: script.py,v 1.36 2006/09/26 16:50:48 wwalker Exp $"
+__version__   = "$Revision: 1.36 $"
+__date__      = "$Date: 2006/09/26 16:50:48 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -69,6 +69,7 @@ class Script:
 
         self.listeners = self.getListeners()
 
+        self.inputEventHandlers = {}
         self.setupInputEventHandlers()
         self.keyBindings = self.getKeyBindings()
         self.brailleBindings = self.getBrailleBindings()
@@ -99,6 +100,25 @@ class Script:
         """
         return keybindings.KeyBindings()
 
+    def getKeyBindingsForInputHandler(self, inputEventHandler):
+        """ Returns a KeyBindings object with the list of KeyBindings that
+        matche the passed inputEventHandler as argument (at least the
+        inputEventHandler that has the same handler function)
+
+        Arguments:
+        - inputEventHandler: an instance of input_event.InputEventHandler
+
+        Returns an instance of keybindings.KeyBindings populated with
+        keybindings.KeyBinding instances that match the inputEventHandler.
+        """
+        matches = keybindings.KeyBindings()
+
+        for binding in self.keyBindings.keyBindings:
+            if inputEventHandler._function == binding.handler._function:
+                matches.add(binding)
+
+        return matches
+
     def getBrailleBindings(self):
         """Defines the braille bindings for this script.
 
@@ -107,6 +127,24 @@ class Script:
         """
         return {}
 
+    def getBrailleCommandsForInputHandler(self, inputEventHandler):
+        """Returns a list of BrlTTY commands (they're in braille.py) that
+        match the given inputEventHandler passed as argument.
+
+        Arguments:
+        - inputEventHandler: an instance of input_event.InputEventHandler
+
+        Returns a list (possibly empty) of BrlTTY commands (they're in
+        braille.py) that match the given inputEventHandler passed.
+        """
+        matches = []
+
+        for command,handler in self.brailleBindings.iteritems():
+            if inputEventHandler._function == handler._function:
+                matches.append(command)
+
+        return matches
+
     def getBrailleGenerator(self):
         """Returns the braille generator for this script.
         """
