@@ -23,9 +23,9 @@ class.  For those wishing to override the speech generators, however,
 one can create a new instance and replace/extend the speech generators
 as they see fit."""
 
-__id__        = "$Id: speechgenerator.py,v 1.75 2006/07/28 17:33:17 wwalker Exp $"
-__version__   = "$Revision: 1.75 $"
-__date__      = "$Date: 2006/07/28 17:33:17 $"
+__id__        = "$Id: speechgenerator.py,v 1.77 2006/09/14 22:57:28 wwalker Exp $"
+__version__   = "$Revision: 1.77 $"
+__date__      = "$Date: 2006/09/14 22:57:28 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -1470,6 +1470,7 @@ class SpeechGenerator:
             if parent == stopAncestor:
                 break
             if (parent.role != rolenames.ROLE_FILLER) \
+                and (parent.role != rolenames.ROLE_LAYERED_PANE) \
                 and (parent.role != rolenames.ROLE_SPLIT_PANE) \
                 and (parent.role != rolenames.ROLE_SCROLL_PANE) \
                 and (parent.role != rolenames.ROLE_UNKNOWN):
@@ -1485,7 +1486,7 @@ class SpeechGenerator:
                    and (((not label) or (len(label) == 0) \
                          or (not text) or (len(text) == 0))):
                     pass
-                else:
+                elif parent.role != rolenames.ROLE_TABLE_CELL:
                     utterances.append(rolenames.getSpeechForRoleName(parent))
 
                 if text and len(text):
@@ -1493,6 +1494,9 @@ class SpeechGenerator:
                 if label and len(label):
                     utterances.append(label)
 
+                if parent.role == rolenames.ROLE_TABLE_CELL:
+                    utterances.append(rolenames.getSpeechForRoleName(parent))
+
             # [[[TODO: HACK - we've discovered oddness in hierarchies
             # such as the gedit Edit->Preferences dialog.  In this
             # dialog, we have labeled groupings of objects.  The
