@@ -19,9 +19,9 @@
 
 """Provides various utility functions for Orca."""
 
-__id__        = "$Id: util.py 1363 2006-08-23 12:30:59Z oserb $"
-__version__   = "$Revision: 1363 $"
-__date__      = "$Date: 2006-08-23 08:30:59 -0400 (Wed, 23 Aug 2006) $"
+__id__        = "$Id: util.py,v 1.44 2006/09/28 17:25:41 wwalker Exp $"
+__version__   = "$Revision: 1.44 $"
+__date__      = "$Date: 2006/09/28 17:25:41 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -46,7 +46,9 @@ import settings
 import speech
 import speechserver
 
+from chnames import chnames
 from orca_i18n import _ # for gettext support
+from punctuation_settings import punctuation
 
 def isSameObject(obj1, obj2):
     if (obj1 == obj2):
@@ -406,9 +408,9 @@ def findFocusedObject(root):
 
     return None
 
-def isDoubleClick(lastInputEvent, inputEvent):
-    """Return an indication of whether the user has double-clicked a
-    one of the keys on the keyboard.
+def getClickCount(lastInputEvent, inputEvent):
+    """Return the count of the number of clicks a user has made to one of the
+    keys on the keyboard.
 
     Arguments:
     - lastInputEvent: the last input event.
@@ -417,16 +419,19 @@ def isDoubleClick(lastInputEvent, inputEvent):
 
     if not isinstance(lastInputEvent, input_event.KeyboardEvent) or \
        not isinstance(inputEvent, input_event.KeyboardEvent):
-        return False
+        orca_state.clickCount = 0
+        return orca_state.clickCount
 
     if (lastInputEvent.hw_code != inputEvent.hw_code) or \
        (lastInputEvent.modifiers != inputEvent.modifiers):
-        return False
+        orca_state.clickCount = 1
+        return orca_state.clickCount
 
     if (inputEvent.time - lastInputEvent.time) < settings.doubleClickTimeout:
-        return True
+        orca_state.clickCount += 1
     else:
-        return False
+        orca_state.clickCount = 0
+    return orca_state.clickCount+1
 
 def isDesiredFocusedItem(obj, rolesList):
     """Called to determine if the given object and it's hierarchy of
@@ -538,9 +543,15 @@ def textLines(obj):
             #if string[-1:] == "\n":
             #    string = string[0][:-1]
 
+            string = adjustForRepeats(string)
+            if string.isupper():
+                voice = settings.voices[settings.UPPERCASE_VOICE]
+            else:
+                voice = settings.voices[settings.DEFAULT_VOICE]
+
             yield [speechserver.SayAllContext(obj, string,
                                               startOffset, endOffset),
-                   None]
+                   voice]
 
         moreLines = False
         relations = obj.relations
@@ -560,6 +571,77 @@ def textLines(obj):
         if not moreLines:
             done = True
 
+def _addRepeatSegment(segment, line):
+    """Add in the latest line segment, adjusting for repeat characters
+    and punctuation.
+
+    Arguments:
+    - segment: the segment of repeated characters.
+    - line: the current built-up line to characters to speak.
+
+    Returns: the current built-up line plus the new segment, after
+    adjusting for repeat character counts and punctuation.
+    """
+
+    style = settings.verbalizePunctuationStyle
+    isPunctChar = True
+    try:
+        level, action = punctuation[segment[0]]
+    except:
+        isPunctChar = False
+    count = len(segment)
+    if (count >= settings.repeatCharacterLimit) \
+       and (not segment[0] in string.whitespace) \
+       and (isPunctChar and (style <= level)):
+        if punctuation.has_key(segment[0]):
+            repeatChar = chnames[segment[0]]
+        else:
+            repeatChar = segment[0]
+        line += ' ' + str(count) + ' ' +  repeatChar  + " characters "
+    else:
+        line += segment
+
+    return line
+
+def adjustForRepeats(line):
+    """Adjust line to include repeat character counts.
+    As some people will want this and others might not,
+    there is a setting in settings.py that determines
+    whether this functionality is enabled.
+
+    repeatCharacterLimit = <n>
+
+    If <n> is 0, then there would be no repeat characters.
+    Otherwise <n> would be the number of same characters (or more)
+    in a row that cause the repeat character count output.
+    If the value is set to 1, 2 or 3 then it's treated as if it was
+    zero. In other words, no repeat character count is given.
+
+    Arguments:
+    - line: the string to adjust for repeat character counts.
+
+    Returns: a new line adjusted for repeat character counts (if enabled).
+    """
+
+    if (len(line) < 4) or (settings.repeatCharacterLimit < 4):
+        return line
+
+    newLine = ''
+    segment = lastChar = line[0]
+
+    for i in range(1, len(line)):
+        if line[i] == lastChar:
+            segment += line[i]
+        else:
+            newLine = _addRepeatSegment(segment, newLine)
+            segment = line[i]
+
+        lastChar = line[i]
+
+    newLine = _addRepeatSegment(segment, newLine)
+
+    return newLine
+
 def getLinkIndex(obj, characterIndex):
     """A brute force method to see if an offset is a link.  This
     is provided because not all Accessible Hypertext implementations
@@ -600,7 +682,7 @@ def isWordDelimiter(character):
     """
 
     return (character in string.whitespace) \
-           or (character in string.punctuation)
+           or (character in '!*+,-./:;<=>?@[\]^_{|}')
 
 def getFrame(obj):
     """Returns the frame containing this object, or None if this object
@@ -1200,23 +1282,24 @@ def speakTextSelectionState(obj, startOffset, endOffset):
         # characters on either end of the text. We adjust the startOffset and
         # endOffset to exclude them.
         #
-        str = obj.text.getText(startOffset, endOffset)
+        try:
+            str = unicode(obj.text.getText(startOffset, endOffset))
+        except:
+            str = ""
         n = len(str)
 
         # Don't strip whitespace if string length is one (might be a space).
         #
         if n > 1:
             while endOffset > startOffset:
-                if str[n-1] in string.whitespace or \
-                   str[n-1] in string.punctuation:
+                if isWordDelimiter(str[n-1]):
                     n -= 1
                     endOffset -= 1
                 else:
                     break
             n = 0
             while startOffset < endOffset:
-                if str[n] in string.whitespace or \
-                   str[n] in string.punctuation:
+                if isWordDelimiter(str[n]):
                     n += 1
                     startOffset += 1
                 else:
